  (int)(long)&((struct stringpool_t *)0)->stringpool_str380,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str297,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str263,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str476,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str295,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str231,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str460,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str279,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str272,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str510,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str329,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str381,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str594,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str413,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str433,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str320,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str590,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str304,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str574,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str157,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str489,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str117,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str163,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str235,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str131,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str135,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str113,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str281,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str145,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str149,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str270,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str124,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str242,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str138,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str142,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str120,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str245,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str607,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str612,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str324,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str178,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str224,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str296,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str192,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str196,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str174,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str342,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str206,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str308,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str197,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str147,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str528,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str569,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str504,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str547,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str618,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str649,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str792,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str763,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str737,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str845,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str796,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str372,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str298,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str387,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str397,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str291,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str211,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str277,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str116,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str283,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str323,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str233,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str249,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str252,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str156,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str580,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str668,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str696,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str641,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str284,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str345,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str77,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str435,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str555,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str421,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str260,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str604,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str548,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str571,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str278,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str426,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str210,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str354,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str327,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str340,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str18,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str470,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str241,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str310,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str995,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str979,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str593,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str356,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str194,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str721,
  (int)(long)&((struct stringpool_t *)0)->stringpool_str405,
